<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPTee_Ajax' )) {

    class IPTee_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            'iptee_update'            => 'update',
            'iptee_delete'            => 'delete',
            'iptee_setting'           => 'setting',
            'iptee_get_slug'          => 'get_slug',
            'iptee_getoptin'          => 'get_optin',
            'iptee_save_email'        => 'save_email',
            'iptee_getchart'          => 'get_chart'
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['iptee'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Update
         *
         * @return void
         */
        public function update()
        {
            $redirect = false;
            $is_add   = false;
            $error    = true;
            if ( ! empty( $_POST['isadd'] )) {
                $is_add = true;
            }
            if ( ! empty( $_POST['contest_id'] )) {
                $contestId = absint( $_POST['contest_id'] );
                if ( $contest = get_post( $contestId ) ) {
                    $this->_update_contest( $contest );
                } else {
                    $contestId = 0;
                }
            } else {
                $contestId = $this->_add_contest();
            }
            if ( $contestId )
            {
                $error = false;
                $model = new IPTee_Model();
                $model->save_setting( $contestId );
            }
            if ( $error ) {
                $status  = 0;
                $contestId  = 0;
                if ( $is_add ) {
                    $message = __( 'Failed to create a contest page.', 'wp_tee_contest' );
                } else {
                    $message = __( 'Failed to save contest page.', 'wp_tee_contest' );
                }
            } else {
                $status = 1;
                if ( $is_add ) {
                    $message  = __( 'Successfully create a contest page.', 'wp_tee_contest' );
                    $redirect = admin_url() . 'admin.php?page=iptee&action=edit&id=' . $contestId . '&create=1&tab=iptee-section-seo';
                } else {
                    $message = __( 'Successfully to save contest page.', 'wp_tee_contest' );
                }
            }
            $result = array(
                'status'    => $status,
                'message'   => $message,
                'contestid' => $contestId
            );
            if ( $redirect ) {
                $result['redirect'] = $redirect;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Add new contest page
         *
         * @return int
         */
        protected function _add_contest()
        {
            global $user_ID;
            
            if ( empty( $_POST['name'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            $dataPost = array(
                'post_status'  => $status, 
                'post_type'    => 'iptee-item', 
                'post_author'  => $user_ID,
                'post_title'   => $title,
                'post_content' => ''
            );
            if ( ! empty( $_POST['slug'] )) {
                $dataPost['post_name'] = apply_filters( 'pre_term_name', $_POST['slug'] );
            }
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Update contest page
         *
         * @param  object $contest
         * @return boolean
         */
        protected function _update_contest( $contest )
        {
            $result   = 0;
            $dataPost = array();
            if ( ! empty( $_POST['name'] ) && $_POST['name'] != $contest->post_title ) {
                $dataPost['post_title'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            if ( $_POST['status'] == 'true' ) {
                $status = 'publish';
            } else {
                $status = 'draft';
            }
            if ( $status != $contest->post_status ) {
                $dataPost['post_status'] = $status;
            }
            if ( ! empty( $dataPost )) {
                $dataPost['ID'] = $contest->ID;
                $result = wp_update_post( $dataPost );
            }
            return $result;
        }
        
        /**
         * Processing ajax for delete object
         *
         * @return void
         */
        public function delete()
        {
            $item = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id   = absint( $_REQUEST['id'] );
                $item = get_post( $id );
            }
            if ( ! $item ) {
                echo json_encode( array(
                    'status'   => 0,
                    'message'  => __( 'Error system', 'wp_tee_contest' )
                ) );
                die();
            }
            $result = wp_delete_post( $item->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'   => 1,
                    'message'  => __( 'Successfully remove the contest page', 'wp_tee_contest' ),
                    'redirect' => admin_url() . 'admin.php?page=iptee&delete=1'
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'message' => __( 'Failed to remove the contest page', 'wp_tee_contest' )
                ) );
            }
            die();
        }
        
        /**
         * Get slug
         *
         * @return void
         */
        public function get_slug()
        {
            $data   = array_merge( $_POST, $_GET );
            $postId = 0;
            if ( ! empty( $data['pageid'] )) {
                $postId = absint( $data['pageid'] );
            }
            if ( ! empty( $data['name'] )) {
                $slug = sanitize_title( $data['name'] );
                $slug = wp_unique_post_slug( $slug, $postId, 1, 'iptee-item', 0 );
                echo json_encode( array(
                    'status' => 1,
                    'slug'   => $slug
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Processing ajax for save setting
         *
         * @return void
         */
        public function setting()
        {
            $error = false;
            if ( ! empty( $_POST['base_path'] )) {
                $path = sanitize_title( $_POST['base_path'] );
                update_option( '__iptee_base_path', $path );
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to update settings.', 'wp_tee_contest' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to update settings.', 'wp_tee_contest' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Save setting
         *
         * @param  string $name
         * @return boolean
         */
        protected function _save_setting( $name )
        {
            if ( ! empty( $_POST[$name] ))
            {
                $shareId = absint( $_POST[$name] );
                if ( $share = get_post( $shareId ))
                {
                    update_option( '__iptee_' . $name, $shareId );
                }
            } else {
                update_option( '__iptee_' . $name, 0 );
            }
            return true;
        }
        
        /**
         * Get responder data
         *
         * @return void
         */
        public function get_optin()
        {
            if ( ! empty( $_POST['html'] ))
            {
                $html = str_replace( "'", '"', $_POST['html'] );
                $data = IPTee_Form::parse( $html );
                echo json_encode( array(
                    'status'    => 1,
                    'data'      => $data
                ) );
                die();
            }
            echo json_encode( array(
                'status'  => 0
            ) );
            die();
        }
        
        /**
         * Processing ajax for save statistic data
         *
         * @return void
         */
        public function save_stat()
        {
            $error = true;
            if ( ! empty( $_POST['page_id'] ) && ! empty( $_POST['type'] )) 
            {
                $page_id = absint( $_POST['page_id'] );
                if ( $page = get_post( $page_id ))
                {
                    $type  = apply_filters( 'pre_term_name', $_POST['type'] );
                    $model = new IPTee_Model();
                    $model->save_stat( $page, $type );
                    
                    $error = false;
                }
            }
            if ( $error ) {
                $status = 0;
                $msg    = __( 'Failed to save statistic data.', 'wp_tee_contest' );
            } else {
                $status = 1;
                $msg    = __( 'Successfully to save statistic data.', 'wp_tee_contest' );
            }
            echo json_encode( array(
                'status'    => $status,
                'message'   => $msg
            ) );
            die();
        }
        
        /**
         * Get chart
         *
         * @return void
         */
        public function get_chart()
        {
            $data = array_merge( $_POST, $_GET );
            if ( ! empty( $data['pageid'] ) && ! empty( $data['type'] )) 
            {
                $pageid    = absint( $data['pageid'] );
                $type      = apply_filters( 'pre_term_name', $data['type'] );
                $dateStart = false;
                $dateEnd   = false;
                if ( ! empty( $data['start'] ) && ! empty( $data['end'] )) {
                    $timeEnd   = strtotime( $data['end'] );
                    $timeStart = strtotime( $data['start'] );
                    $dateStart = gmdate("Y-m-d", $timeStart);
                    $dateEnd   = gmdate("Y-m-d", $timeEnd);
                }
                $model     = new IPTee_Model();
                $chart     = array();
                $results   = $model->get_statistic_data( $pageid, $type, $dateStart, $dateEnd );
                
                if ( ! empty( $results )) {
                    foreach( $results as $data ) {
                        $timestamp = strtotime( $data->gdate );
                        $phpdate   = getdate($timestamp);
                        if ( $type == 'ctr' ) {
                            $value = 0;
                            if ( ! empty( $data->click ) && ! empty( $data->view )) {
                                $rate  = 100 * intval($data->click) / intval($data->view);
                                $rate  = round( $rate, 2 );
                                $value = $rate;
                            }
                        } else {
                            $value = (int)$data->value;
                        }
                        $chart[] = array(
                            'value'    => $value,
                            'year'     => $phpdate['year'],
                            'mon'      => $phpdate['mon'] - 1,
                            'day'      => $phpdate['mday'],
                        );
                    }
                }
                if ( $type == 'view' ) {
                    $label = __( 'Views', 'wp_tee_contest' );
                } elseif ( $type == 'order' ) {
                    $label = __( 'Orders', 'wp_tee_contest' );
                } elseif ( $type == 'share' ) {
                    $label = __( 'Shares', 'wp_tee_contest' );
                } elseif ( $type == 'contest' ) {
                    $label = __( 'Contestants', 'wp_tee_contest' );
                } elseif ( $type == 'ctr' ) {
                    $label = __( 'CTR (in %)', 'wp_tee_contest' );
                } else {
                    $label = __( 'Data', 'wp_tee_contest' );
                }
                echo json_encode( array(
                    'status'            => 1,
                    'labelDate'         => __( 'Date', 'wp_tee_contest' ),
                    'labelValue'        => $label,
                    'data'              => $chart
                ) );
            } else {
            
                echo json_encode( array(
                    'status' => 0
                ) );
            }
            die();
        }
        
        /**
         * Save email
         *
         * @return void
         */
        public function save_email()
        {
            $pageid = 0;
            if ( ! empty( $_POST['pageid'] )) {
                $pageid = absint( $_POST['pageid'] );
            }
            $data = array();
            $data['cnt_join_date'] = date( 'c' );
            
            if ( ! empty( $_POST['email'] )) {
                $data['cnt_email'] = sanitize_email( $_POST['email'] );
            }
            if ( ! empty( $_POST['name'] )) {
                $data['cnt_name'] = apply_filters( 'single_post_title', $_POST['name'] );
            }
            $data['page_id'] = $pageid;
            $data['cnt_ip']  = $_SERVER['REMOTE_ADDR'];
            $data['cnt_key'] = md5( $_SERVER['REMOTE_ADDR'] . $data['cnt_email'] . time() );
            
            $model = new IPTee_Model();
            if ( ! $page = get_post( $pageid ))
            {
                $json_data = array(
                    'status'    => '0',
                    'message'   => __( 'Contest not found.', 'wp_tee_contest' )
                );
                echo json_encode( $json_data );
                die();
            }
            if ( $contestant = $model->get_contestant_byemail( $pageid, $data['cnt_email'] )) 
            {
                $json_data = array(
                    'status'    => '0',
                    'message'   => __( 'You ever try to follow this contest.', 'wp_tee_contest' )
                );
                echo json_encode( $json_data );
                die();
            }
            //Insert data contestant
            $result = $model->insert_contestant( $data );
            
            //Save stat
            $model = new IPTee_Model();
            $model->save_stat( $page, 'contest' );
            
            if ( $result ) 
            {
                $json_data = array(
                    'status'    => '1',
                    'id'        => $result,
                    'pageid'   => $pageid,
                    'message'   => __( 'Your personal data we have saved, and you have chance to get the free t-shirt.', 'wp_tee_contest' )
                );
            } else {
                $json_data = array(
                    'status'    => '0',
                    'message'   => __( 'You can not get the free t-shirt because of a system error, please try again letter.', 'wp_tee_contest' )
                );
            }
            echo json_encode( $json_data );
            die();
        }
    }
}