<?php
if ( ! class_exists( 'IPTee_Factory' )) {

    /**
     * Class for create landing page
     */
    class IPTee_Factory
    {
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Render page
         *
         * @return string
         */
        public function render()
        {
            global $wp_query, $user_ID;
            if ( ( isset( $wp_query->query['iptee'] ) && isset( $wp_query->query['contest_name'] ) ) || 
                 isset( $wp_query->query['contest_id'] ) ) 
            {
                $page = $wp_query->post;
                
                if ( $page->post_status == 'publish' ) 
                {
                    $setting = new IPTee_Setting( $page->ID, '__iptee-setting' );
                    
                    $this->query     = $wp_query;
                    $this->setting   = $setting;
                    $this->page      = $page;
                    $this->basepath  = IPTEE_PATH . 'theme/';
                    $this->baseurl   = IPTEE_BASE_URL . 'theme/';
                    $this->cssurl    = $this->baseurl . 'css/';
                    $this->jsurl     = $this->baseurl . 'js/';
                    $this->imgurl    = $this->baseurl . 'img/';
                    $this->pageurl   = $this->get_page_link( $page );
                    $this->pagetitle = $this->get_page_title( $page );
                    $this->is_ready  = $this->_is_ready();
                    $this->is_expiry = $this->_check_expiry();
                    
                    //Check expiry
                    $expiryUrl = $setting->getSetting( 'countdown_expiry_url' );
                    if ( $this->is_expiry && $expiryUrl ) {
                        wp_redirect( $expiryUrl );
                    }
                    
                    //Save stat
                    $this->_save_stat();
                    
                    //Include file template
                    $template = $this->_get_template();
                    if ( file_exists( $template )) {
                        include( $template );
                    } else {
                        echo '<h1>Error System</h1>';
                    }
                    exit();
                }
                else 
                {
                    $query->query_vars['post_type'] = 'iptee-item-nothing';
                }
            }
        }
        
        /**
         * Get page link
         *
         * @param object $page
         * @return void
         */
        public function get_page_link( $page )
        {
            if ( get_option( 'permalink_structure' ) )  {
                $base = get_option( '__iptee_base_path', 'contest' );
                $link = get_home_url() . "/$base/" . $page->post_name;
            } else {
                $link = get_home_url() . '/?contest_id=' . $page->ID;
            }
            return $link;
        }
        
        /**
         * Get page title
         *
         * @param object $page
         * @return void
         */
        public function get_page_title( $page )
        {
            $st    = $this->setting;
            $title = $st->getSetting( 'meta_title' );
            if ( empty( $title )) {
                $title = $st->getSetting( 'title', 'Contest' );
            }
            $title = stripslashes( $title );
            return $title;
        }
        
        /**
         * Get share link
         *
         * @param  string $type
         * @return string
         */
        public function get_share_link( $type )
        {
            $pagetitle = urlencode( $this->pagetitle );
            $pageurl   = urlencode( $this->pageurl );
            $actions   =  array(
                'facebook'      => 'http://www.facebook.com/share.php?u=' . $pageurl,
                'twitter'       => 'https://twitter.com/share?url=' . $pageurl . '&text=' . $pagetitle,
                'googleplus'    => 'https://plusone.google.com/_/+1/confirm?hl=en&url=' . $pageurl,
                'pinterest'     => 'http://pinterest.com/pin/create/button/?url=' . $pageurl . '&media=&description=' . $pagetitle,
                'linkedin'      => 'http://www.linkedin.com/shareArticle?mini=true&url=' . $pageurl .'&title=' . $pagetitle,
                'tumblr'        => 'http://www.tumblr.com/share?v=3&u=' . $pageurl,
                'stumbleupon'   => 'http://www.stumbleupon.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
                'digg'          => 'http://digg.com/submit?url=' . $pageurl . '&title=' . $pagetitle,
                'email'         => 'mailto:?subject=' . $pagetitle
            );
            $link = '#';
            if ( array_key_exists( $type, $actions )) {
                $link = $actions[$type];
            }
            return $link;
        }
        
        /**
         * Get Google font
         *
         * @return string
         */
        public function get_google_font()
        {
            $fonts   = array();
            $fonts[] = $this->setting->getSetting( 'top_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'content_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'countdown_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'footer_font_family', 'roboto' );
            $fonts[] = $this->setting->getSetting( 'ribbon_font_family', 'roboto' );
            $fonts   = array_unique( $fonts );
            
            $fams  = array();
            $links = IPTee_Font::getLinks();
            foreach( $fonts as $font ) 
            {
                if ( array_key_exists( $font, $links )) 
                {
                    $fams[] = $links[$font];
                }
            }
            
            $family  = implode( '|', $fams );
            $url     = 'http://fonts.googleapis.com/css?family=' . $family;
            return $url;
        }
        
        /**
         * Get general
         *
         * @param string $page_name
         * @param string $ext
         * @return void
         */
        public function general( $page_name, $ext = '.php' )
        {
            $path = IPTEE_PATH . 'theme/general/' . $page_name . $ext;
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Inc
         *
         * @param  string $path
         * @param  string $exr
         * @return void
         */
        public function inc( $path, $ext = '.php' )
        {
            $path = $this->basepath . $path . $ext;
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Get page template
         *
         * @param object $page
         * @return void
         */
        protected function _get_template()
        {
            $this->theme_root = $this->baseurl;
            $template = $this->basepath . 'index.php';
            return $template;
        }
        
        /**
         * Save stat
         *
         * @return void
         */
        protected function _save_stat()
        {
            $model = new IPTee_Model();
            $model->save_stat( $this->page, 'view' );
        }
        
        /**
         * Check expiry
         *
         * @return boolean
         */
        protected function _check_expiry()
        {
            $expiry = false;
            if ( $this->setting->getSetting( 'countdown_activate', 'true' ) == 'true' ) 
            {
                $date =  $this->setting->getSetting( 'expiry_date' );
                $time =  $this->setting->getSetting( 'expiry_time' );
                if ( $date && $time ) {
                    $dtime = $date . ' ' . $time . ':00';
                    $timestamp = strtotime( $dtime );
                    $nowtime   = time();
                    if ( $nowtime > $timestamp ) {
                        $expiry = true;
                    }
                }
            }
            return $expiry;
        }
        
        /**
         * Check wheater user ready follow the contest
         *
         * @return boolean
         */
        protected function _is_ready()
        {
            $ready = false;
            $opt   = $this->setting->getSetting( 'restricted_contestant', 'true' );
            if ( $opt == 'true' ) {
                if ( ! empty( $_COOKIE['_iptee_contest_ready'] )) {
                    $ready = true;
                } elseif ( $this->_check_ip() ) {
                    $ready = true;
                }
            }
            return $ready;
        }
        
        /**
         * Check ip
         *
         * @return boolean
         */
        protected function _check_ip()
        {
            $ready = false;
            $ip    = $_SERVER['REMOTE_ADDR'];
            $model = new IPTee_Model();
            $cont  = $model->get_contestant_byip( $this->page->ID, $ip );
            if ( $cont ) {
                $ready = true;
            }
            return $ready;
        }
    }
}