/*
 *===========================================================
 * UI
 *===========================================================
 */
(function($)
{
    "use strict";
    
    //Inherit function
    function inherit( proto ) 
    {
        function F() {}
        F.prototype = proto
        return new F
    }

    /*
     *===========================================================
     * Ui prototype
     *===========================================================*/
    function ui_construct( options ){};
    
    ui_construct.prototype = 
    {
        
        vars:               {},
        class_prefix:       'ipbe-',
        class_main:         '-main',
        class_title:        '-title',
        class_content:      '-content',
        class_disabled:     'disabled',
        class_close:        'ui-close',
        label_close:        'x',
        image_base:         '',
        
        top_margin:         '80px',
        overlay_speed:      600,
        main_speed:         400,
        show_speed:         4000,
        
        show_after:         function(){},
        hide_after:         function(){},
        
        popup_body: function( class_root, content, title, close )
        {
            var body = $( '<div class="'+class_root+'"></div>' );
            var main = $( '<div class="'+class_root + this.class_main+'"></div>' );
            if ( title ) 
            {
                var _title = $( '<div class="'+class_root + this.class_title+'"></div>' )
                                .append( '<h3>'+title+'</h3>' );
                if ( close ) 
                {
                    var _close = $( '<a href="#">'+this.label_close+'</a>' );
                    this.popup_close( _close, class_root );
                    
                    _title.append( 
                        $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close ) 
                    );
                }
                main.append( _title );
            }
            if ( content ) {
                main.append( 
                    $( '<div class="'+class_root + this.class_content+'"></div>' ).append( content )
                );
            }
            body.append( main );
            return body;
        },
        popup_show: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            popup.show();
            main.css( 'margin-top', '-40%' )
                .animate({marginTop: this.top_margin}, this.main_speed, this.show_after);
        },
        popup_hide: function( popup )
        {
            var c_root = popup.attr( 'class' );
            var main   = $( '.'+c_root+this.class_main, popup );
            
            popup.animate( {opacity: 0}, this.overlay_speed, function(){
                $(this).css( 'opacity', 1 )
                       .hide();
            });
            main.animate( {marginTop: '-60%'}, this.main_speed, this.hide_after);
        },
        popup_close: function( button, class_popup )
        {
            var ui = this;
            button.click( function(){
                var popup = $( '.'+class_popup );
                ui.popup_hide( popup );
                return false;
            });
        },
        is_load: function( selector )
        {
            if ( $( selector ).length > 0 ) {
                return true;
            }
            return false;
        },
        set_vars: function( options )
        {
            this.vars = $.extend(this.vars, options);
        },
        set_base_vars: function( options )
        {
            this.vars = $.extend(this, options);
        },
        go_to: function( selector )
        {
            var pos = $( selector ).position();
            $('html, body').animate({scrollTop: ( pos.top )}, 600);
            return false;
        }
    };
    
    /*
     * Modal Class
     **/
    function modal(){};
    modal.prototype = inherit( ui_construct.prototype );
    //Modal message
    modal.prototype.ajax = function( id, url )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var modal   = this.popup_body( c_root, '', false, false ).appendTo( $( 'body' ) );
        modal.addClass( class_type )
             .attr( 'id', id );
        
        this.popup_show( modal );
    };
    
    /*
     * Loader Class
     **/
    function loader(){};
    loader.prototype = inherit( ui_construct.prototype );
    //Properties
    loader.prototype.class_root     = 'ui-loader';
    loader.prototype.loader_file    = 'loading.gif';
    //Show loader
    loader.prototype.show = function()
    {
        var loader = this.create();
        this.popup_show( loader );
    };
    //Hide loader
    loader.prototype.hide = function()
    {
        var loader = this.create();
        this.popup_hide( loader );
    };
    //Create loader
    loader.prototype.create = function()
    {
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else 
        {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = this.popup_body( c_root, image, false, false ).appendTo( $( 'body' ) );
            loader.hide();
            
            return loader;
        }
    };
    
    
    /*
     * Inline loader Class
     **/
    function iloader(){};
    iloader.prototype = inherit( ui_construct.prototype );
    //Properties
    iloader.prototype.class_root   = 'ui-inline-loader';
    iloader.prototype.loader_file  = 'spin.gif';
    //Loader show
    iloader.prototype.show = function( button )
    {
        button.attr( 'disabled', 'disabled' );
        this.create( button ).show();
    };
    //Loader hide
    iloader.prototype.hide = function( button )
    {
        button.removeAttr( 'disabled' );
        this.create( button ).hide();
    };
    //Creating loader
    iloader.prototype.create = function( button )
    {
        var root   = button.parent();
        var lclass = this.class_prefix + this.class_root;
        if ( $( '.'+lclass, root ).length > 0 ) {
            var loader = $( '.'+lclass, root );
        } else {
            var image  = '<img src="'+this.image_base+this.loader_file+'" alt="Loading...">';
            var loader = $( '<span class="'+lclass+'"></span>' )
                            .append( image )
                            .css( 'margin-left', '8px' );
        }
        button.after( loader );
        return loader;
    };
    
    
    /*
     * Confirm popup
     **/
    function confirm( options )
    {
        var defaults = {
            title:      'Confirmation',
            info:       '',
            yes_label:  'Yes',
            no_label:   'Cancel',
            yes_class:  'btn btn-danger',
            no_class:   'btn btn-success',
            action:     function( object ){}
        };
        this.vars = $.extend(defaults, options);
    };
    confirm.prototype = inherit( ui_construct.prototype );
    //Properties
    confirm.prototype.class_root = 'ui-confirm';
    //Confirm show
    confirm.prototype.show = function( object )
    {
        var confirm = this.create( object );
        this.popup_show( confirm );
    };
    //Confirm hide
    confirm.prototype.hide = function( object )
    {
        var confirm = this.create( object );
        this.popup_hide( confirm );
    };
    //Creating confirm
    confirm.prototype.create = function( object )
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            $( '.'+c_root ).remove();
        }
        //Create confirm
        var yesbtn = $( '<a href="#" class="ip-confirm-yes '+this.vars.yes_class+'">'+this.vars.yes_label+'</a>' );
        var nobtn  = $( '<a href="#" class="ip-confirm-no '+this.vars.no_class+'">'+this.vars.no_label+'</a>' );
        
        yesbtn.click( function(){
            ui.vars.action( object, ui );
            return false;
        });
        this.popup_close( nobtn, c_root );
        
        var content = $( '<div class="'+c_root+'-inner"></div>' )
            .append( '<p>'+this.vars.info+'</p>' )
            .append( 
                $( '<div class="'+c_root+'-actions"></div>' )
                    .append( yesbtn )
                    .append( nobtn )
            );
        
        var confirm = this.popup_body( c_root, content, this.vars.title, false ).appendTo( $( 'body' ) );
        confirm.hide();
        
        return confirm;
    };
    
    
    /*
     * Alert popup
     **/
    function alert( options )
    {
        var defaults = {
            message:        '',
            label_button:   'Ok',
            class_root:     '',
            class_button:   'btn btn-danger',
            after:          function(){}
        };
        this.vars = $.extend(defaults, options);
    };
    alert.prototype = inherit( ui_construct.prototype );
    //Properties
    alert.prototype.class_root = 'ui-alert';
    //Alert show
    alert.prototype.show = function( message )
    {
        this.vars.message = message;
        var alert = this.create();
        this.popup_show( alert );
    };
    //Alert hide
    alert.prototype.hide = function()
    {
        var alert = this.create();
        this.hide_after = this.vars.after;
        this.popup_hide( alert );
    };
    //Creating alert
    alert.prototype.create = function()
    {
        var ui     = this;
        var c_root = this.class_prefix + this.class_root;
        if ( this.is_load( '.'+c_root )) {
            return $( '.'+c_root );
        } else 
        {
            var button = $( '<a href="#" class="'+this.vars.class_button+'">'+this.vars.label_button+'</a>' );
            this.popup_close( button, c_root );
            
            var c_info  = c_root + '-inner';
            if ( this.vars.class_root != '' ) {
                c_info += ' ' + this.vars.class_root;
            }
            var content = $( '<div class="'+c_info+'"></div>' )
                .append( '<p>'+this.vars.message+'</p>' )
                .append( 
                    $( '<div class="'+c_root+'-actions"></div>' )
                        .append( button )
                );
            
            var popup  = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
            popup.hide();
            
            return popup;
        }
    };
    
    
    /*
     * Message
     **/
    function message(){};
    message.prototype = inherit( ui_construct.prototype );
    //Properties
    message.prototype.class_modal = 'ui-modal-message';
    message.prototype.class_block = 'ui-message';
    //Modal message
    message.prototype.modal = function( message, class_type )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_modal;
        var content = '<p>'+message+'</p>';
        var msg     = this.popup_body( c_root, content, false, false ).appendTo( $( 'body' ) );
        msg.addClass( class_type )
           .show()
           .animate({top: "0"}, ui.overlay_speed, function(){
                var object = $( this );
                setTimeout( function(){
                    object.animate({top: '-100px'}, ui.overlay_speed, function(){
                        object.remove();
                    });
                }, ui.show_speed);
            });
    };
    //Bloack message
    message.prototype.block = function( message, class_type, block, close )
    {
        var ui      = this;
        var c_root  = this.class_prefix + this.class_block;
        var parent  = block.parent();
        
        $( '.'+c_root, parent ).remove();
        
        var msg = $( '<div></div>' );
        msg.addClass( c_root )
           .addClass( class_type )
           .append( '<p>'+message+'</p>' );
        
        if ( close ) 
        {
            var _close = $( '<a href="#">'+this.close_label+'</a>' );
            _close.click( function()
            {
                var _msg = $(this).parents( '.'+c_root );
                _msg.animate({opacity: "0"}, ui.overlay_speed, function(){
                    _msg.remove();
                });
                return false;
            });
            msg.append( 
                $( '<div class="'+this.class_prefix+this.class_close+'"></div>' ).append( _close ) 
            );
        }
        msg.css( 'opacity', '0' );
        parent.prepend( msg );
        msg.animate({opacity: "1"}, ui.overlay_speed);
    };
    
    //Set global variable
    if ( typeof window.ip_ui == 'undefined' )
    {
        window.ip_ui = 
        {
            base: {
                construct:  ui_construct,
                loader:     loader,
                iloader:    iloader,
                confirm:    confirm,
                message:    message,
                alert:      alert,
                modal:      modal
                
            },
            init: function()
            {
                this.loader  = new this.base.loader(),
                this.iloader = new this.base.iloader(),
                this.confirm = new this.base.confirm(),
                this.message = new this.base.message(),
                this.alert   = new this.base.alert(),
                this.modal   = new this.base.modal()
            }
        };
    }
    
})(jQuery);
/*
 *===========================================================
 * Form Handler
 *===========================================================
 */
(function($)
{
    "use strict";
    
    var delete_confirm_title = '';
    var delete_confirm_info  = '';
    if (typeof ip_ui_message.delete_confirm_title != 'undefined') {
        delete_confirm_title = ip_ui_message.delete_confirm_title;
    }
    if (typeof ip_ui_message.delete_confirm_info != 'undefined') {
        delete_confirm_info = ip_ui_message.delete_confirm_info;
    }
    
    //Prepare ui
    ip_ui.base.construct.prototype.image_base = ipbe_base + 'img/';
    ip_ui.base.confirm.prototype.set_ajax = function( ajax_url )
    {
        this.ajax_url = ajax_url;
    };
    ip_ui.init();
    ip_ui.delete_confirm = new ip_ui.base.confirm();
    
    ip_ui.delete_confirm.set_vars({
        title: delete_confirm_title,
        info: delete_confirm_info,
        yes_class:  'ipbe-btn ipbe-btn-danger',
        no_class:   'ipbe-btn ipbe-btn-default',
        action:     function( object, ui )
        {
            var id = object.data( 'id' );
            ip_ui.loader.show();
            ui.hide( object );
            
            $.ajax({
                url: ui.ajax_url + '&id='+id,
                type: "POST",
                dataType: "json",
                success: function (result) 
                {
                    if ( object.hasClass( 'ipbe-del-edit' ) )
                    {
                        window.location.href = result.redirect;
                    } else 
                    {
                        if ( result.status == '-1' ) {
                            ip_ui.message.modal( result.message, 'alert-danger' );
                        } else {
                            ip_ui.message.modal( result.message, 'alert-success' );
                            ui.vars.remove_element( object, ui );
                        }
                        ip_ui.loader.hide();
                    }
                },
                error: function () {
                    alert( "Error in deleting item." );
                },
            });
        },
        remove_element: function( object, ui )
        {
            var tr = object.parents( 'tr' );
            tr.hide( 'blind' );
            setTimeout( function(){
                tr.remove();
            }, 600);
        }
    });
    
    /**
     * Form handler
     */
    function ip_form( id ){
        this.form   = $( id );
        this.action = this.form.attr( 'action' );
    }
    //Set vars
    ip_form.prototype = 
    {
        //Variables
        button_id:          '.ip-form-submit',
        cont_id:            '.ip-form-cont',
        error_process:      'Error',
        success_process:    'Success',
        ajax_type:          'POST',
        ajax_dataType:      'json',
        
        //Init
        init: function()
        {
            var $this = this;
            //Prepare
            this.prepare();
            //Form submit
            $( this.button_id, $this.form ).click( function()
            {
                if ( $this.validator() ) {
                    if ( $this.before() ) {
                        ip_ui.loader.show();
                        var data   = $this.get_data();
                        var result = $this.process();
                        $this.after( result );
                    }
                }
                $this.error();
                return false;
            });
        },
        //Prepare form
        prepare: function(){},
        //Main process
        process: function()
        {
            var $this = this;
            var data  = $this.get_data();
            $.ajax({
                url: $this.action,
                type: $this.ajax_type,
                dataType: $this.ajax_dataType,
                data: data,
                success: function( result ) {
                    $this.ajax_success( result, $this );
                },
                error: function() {
                    $this.ajax_error( $this );
                }
            });
        },
        //Before process
        before: function()
        {
            return true;
        },
        //After process
        after: function( result ){},
        //Process if error
        error: function(){},
        //Process if ajax success
        ajax_success: function( result, $this )
        {
            $( '.ui-message', $this.form ).remove();
            ip_ui.loader.hide();
            if ( result.status == 1 ) {
                if ( typeof result.redirect != 'undefined' ) {
                    window.location.href = result.redirect;
                } else {
                    if ( typeof result.reset != 'undefined' ) {
                        $this.form[0].reset();
                    }
                    ip_ui.message.modal( result.message, 'alert-success' );
                }
            } else {
                ip_ui.message.modal( result.message, 'alert-danger' );
            }
        },
        //Process if ajax error
        ajax_error: function( $this )
        {
            ip_ui.loader.hide();
            ip_ui.message.modal( $this.error_process, 'alert-danger' );
        },
        
        //Validating form data
        validator: function()
        {
            return true;
        },
        check_empty: function( id, message )
        {
            var input = $( id );
            if ( input.val() == '' ) {
                ip_ui.message.block( message, 'ip-ui-danger', input );
                return true;
            }
            return false;
        },
        
        //Get data form
        get_data: function()
        {
            var root = this.form;
            var selector  = 'input[type=text]';
            selector += ', input[type=hidden]';
            selector += ', input[type=password]';
            selector += ', input[type=radio]:checked';
            selector += ', input[type=checkbox]:checked';
            selector += ', textarea';
            selector += ', select';
            
            var data = '';
            $( selector, root ).each( function(){
                var name  = $(this).attr( 'name' );
                var value = encodeURIComponent( $(this).val() );
                
                if ( data != '' ) {
                    data += '&';
                }
                data += name+'='+value;
            });
            if (typeof tinyMCE !== 'undefined') {
                for ( var edId in tinyMCE.editors ) {
                    
                    if ( edId.length > 1 ) {
                        var value = tinyMCE.editors[edId].getContent();
                        if ( data != '' ) {
                            data += '&';
                        }
                        data += edId+'='+value;
                    }
                }
            }
            data = this.additional_data( data );
            return data;
        },
        additional_data: function( data )
        {
            return data;
        },
        
        //Get tiny mce object
        get_tinymce: function( contentId )
        {
            var content = '';
            if (typeof tinyMCE !== 'undefined') {
                content = tinyMCE.get( contentId ).getContent();
            }
            return content;
        },
        //Set tiny mce object with a content
        set_tinymce: function( contentId, content )
        {
            if (typeof tinyMCE !== 'undefined') {
                tinyMCE.get( contentId ).setContent( content );
            }
        }
    };
    window.ip_form = ip_form;
    
})(jQuery);
/*
 *===========================================================
 * Button Active
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_button_active = function( options ) 
    {
        var defaults  = {
            func_select:      function( button ){}
        };
        var opt = $.extend( defaults, options );
        
        $(this).click( function()
        {
            if ( $(this).hasClass( 'active' )) {
                $(this).removeClass( 'active' );
                $( 'input', $(this) ).val( 'off' );
            } else {
                $(this).addClass( 'active' );
                $( 'input', $(this) ).val( 'on' );
            }
            
            //Select callback
            opt.func_select( $(this) );
            return false;
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Fade Menu
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_fade_menu = function(){
        
        $(this).each( function(){
        
            var mouse_in_menu = false;
            var root = $(this);
            
            $( '.ipbe-menu-link', root ).click( function(){
            
                $( '.ipbe-submenu' ).fadeOut( "fast" );
                $( '.ipbe-menu-link' ).removeClass( 'active' );
            
                var link    = $(this);
                var content = $( '.ipbe-submenu', root );
                
                if ( content.is(":visible") ) {
                    content.fadeOut( "fast" );
                    link.removeClass( 'active' );
                } else {
                    content.fadeIn( "fast" );
                    link.addClass( 'active' );
                }
                return false;
            });
            $( '.ipbe-submenu', root ).hover( function(){
                    mouse_in_menu = true;
                }, function(){
                    mouse_in_menu = false;
            });
            $( "body" ).click(function(){
                if ( ! mouse_in_menu ) {
                    $( '.ipbe-submenu', root ).fadeOut( "fast" );
                    $( '.ipbe-menu-link', root ).removeClass( 'active' );
                }
            });
            $( '.ipbe-submenu a', root ).click(function(){
                $( '.ipbe-submenu', root ).fadeOut( "fast" );
                $( '.ipbe-menu-link', root ).removeClass( 'active' );
            });
        });
    };
    
    
})(jQuery);
/*
 *===========================================================
 * Fancy Option
 *===========================================================*/
(function($)
{
    "use strict";
    
    //Fancy option
    $.fn.ipbe_fancy_option = function(options){
    
        var defaults  = {
            func_select: function( option ){},
        };
        var options = $.extend( defaults, options );
        
        //Setup
        $( '.ipbe-select li:first-child' ).addClass( 'ipbe-item-selected' );
        
        $(this).each( function(){
        
            var option  = $(this);
            var in_menu = false;
            
            $( '.ipbe-selected', option ).click( function(){
                
                var menu   = $(this);
                var select = $( '.ipbe-select', option );
                
                if ( select.is(":visible") ) {
                    select.fadeOut( "fast" );
                    menu.removeClass( 'active' );
                } else {
                    
                    $( '.ipbe-select' ).each( function(){
                        $(this).fadeOut( "fast" );
                        $(this).parents( '.ipbe-selected' ).removeClass( 'active' );
                    });
                    select.fadeIn( "fast" );
                    menu.addClass( 'active' );
                }
                return false;
            });
            $( '.ipbe-select', option ).hover( function(){
                    in_menu = true;
                }, function(){
                    in_menu = false;
            });
            $( "body" ).click(function(){
                if ( ! in_menu ) {
                    $( '.ipbe-select', option ).fadeOut( "fast" );
                    $( '.ipbe-selected', option ).removeClass( 'active' );
                }
            });
            
            $( 'li', option ).click( function(){
            
                var item  = $(this);
                var label = $( '.ipbe-select-label', item ).clone().html();
                var data  = item.data( 'select' );
                $( '.ipbe-selected .ipbe-selected-box', option ).html( label );
                $( '.ipbe-select li', option ).removeClass( 'ipbe-item-selected' );
                item.parents( 'li' ).addClass( 'ipbe-item-selected' );
                $( '.ipbe-input-select', option ).val( data );
                
                //Hide Select box
                $( '.ipbe-select', option ).fadeOut( "fast" );
                $( '.ipbe-selected', option ).removeClass( 'active' );
                
                options.func_select( option );
            });
        
        });
    
    };
    
})(jQuery);
/*
 *===========================================================
 * Select image input
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_image_option = function( options ) 
    {
        var defaults  = {
            option_class:   'ipbe-option',
            selected_class: 'ipbe-active',
            input_class:    'ipbe-selected',
            func_select:    function( item ){}
        };
        var options = $.extend( defaults, options );
        
        var root = $(this);
        root.each( function()
        {
            $( '.'+options.option_class, root ).click( function(e)
            {
                $( '.'+options.option_class, root ).removeClass( options.selected_class );
                $(this).addClass( options.selected_class );
                
                var id = $(this).data( 'id' );
                $( '.'+options.input_class, root ).val( id );
                
                //Callback
                options.func_select( $(this) );
                
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Image preview
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_image_preview = function( options ) 
    {
        var defaults  = {
            root_class:     'ipbe-preview-link',
            link_class:     'ipbe-preview-link',
            popup_id:       'ipbe-image-preview-popup'
        };
        var options = $.extend( defaults, options );
        
        var item = $(this);
        item.each( function()
        {
            var root = $(this);
            $( '.'+options.link_class, root ).click( function(e)
            {
                $( '#'+options.popup_id ).remove();
                
                var img   = $( 'img', root );
                var src   = img.data( 'big-image' );
                var popup = ip_ui.modal.popup_body( 'ipbe-ui-modal', '<img src="' + src + '" alt="">', 'Image Preview', true )
                                .appendTo( $( 'body' ) )
                                .attr( 'id', options.popup_id )
                                .hide();
                
                ip_ui.modal.popup_show( popup );
                
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Button Active
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_list_delete = function( url ) 
    {
        $(this).each( function()
        {
            var button = $(this);
            button.click( function()
            {
                ip_ui.delete_confirm.set_ajax( url );
                ip_ui.delete_confirm.set_vars({
                    remove_element: function( object, ui ){
                        var cont   = object.parents( '.ipbe-manage-list' );
                        var item   = object.parents( '.ipbe-list-item' );
                        var length = $( '.ipbe-list-item', cont ).length;
                        
                        item.hide( 'blind' );
                        if ( length == 1 ) {
                            $( '.ipbe-list-empty', cont ).show();
                        }
                        setTimeout( function(){
                            item.remove();
                        }, 600);
                    }
                });
                ip_ui.delete_confirm.show( button );
                return false;
            });
        });
    };
    
    $.fn.ipbe_list_table_delete = function( url ) 
    {
        $(this).each( function()
        {
            var button = $(this);
            button.click( function()
            {
                ip_ui.delete_confirm.set_ajax( url );
                ip_ui.delete_confirm.show( button );
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Modal
 *===========================================================*/
(function($)
{
    "use strict";
    
    /**
     * Modal link
     */
    $.fn.ip_modal = function()
    {
        $(this).each( function()
        {
            var link  = $(this);
            var href  = link.attr( 'href' );
            var popup = $( href );
            
            ip_ui.modal.top_margin = '10px';
            
            //Link close 
            var close_class = ip_ui.modal.class_prefix + ip_ui.modal.class_close;
            $( '.'+close_class, popup ).click( function()
            {
                ip_ui.modal.popup_hide( popup );
                return false;
            });
            
            //Link open
            link.click( function()
            {
                ip_ui.modal.popup_show( popup );
                return false;
            });
        });
    };
    
    /**
     * Modal ajax handler
     */
    $.fn.ip_modal_ajax = function( options )
    {
        var defaults  = {
            modalSelector:  '.ipbe-ui-modal',
            mainSelector:   '.ipbe-ui-modal-content',
            loaderUrl:      '',
            getAjaxUrl:     function( button ){},
            getAjaxData:    function( button ){
                return '';
            },
            ajaxSuccess:     function( result, button, popup ){},
            afterClosePopup: function( button, popup ){}
        };
        var options = $.extend( defaults, options );
        
        var popup  = $( options.modalSelector );
        var main   = $( options.mainSelector, popup );
        
        //Button close 
        var close_class = ip_ui.modal.class_prefix + ip_ui.modal.class_close;
        $( '.'+close_class, popup ).click( function()
        {
            ip_ui.modal.popup_hide( popup );
            options.afterClosePopup( popup );
            return false;
        });
        
        $(this).each( function()
        {
            var button = $(this);
            //Button open
            button.click( function()
            {
                //Insert Loader
                main.html( '<img class="loader" src="' + options.loaderUrl + '" alt="Loading...">' );
                
                var url  = options.getAjaxUrl( button );
                var data = options.getAjaxData( button );
                $.ajax({
                    url: url,
                    type: "POST",
                    dataType: "html",
                    data: data,
                    success: function (result) 
                    {
                        options.ajaxSuccess( result, button, popup, main );
                    }
                });
                
                ip_ui.modal.popup_show( popup );
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * On Off Button
 *===========================================================*/
(function($)
{
    "use strict";
    
    /**
     * On Off button
     */
    $.fn.ipbe_btn_onoff = function( options ) 
    {
        var defaults  = {
            func_select: function( button ){},
        };
        var options = $.extend( defaults, options );
        
        $(this).each( function(){
        
            var cont = $(this);
            $( '.ipbe-btn', cont ).click( function()
            {
                var value = $(this).data( 'value' );
                if ( ! $(this).hasClass( 'active' ) ) {
                    $( 'button', cont ).removeClass( 'active' );
                    $( 'button', cont ).removeClass( 'ipbe-btn-success' );
                    $( 'button', cont ).removeClass( 'ipbe-btn-danger' );
                    if ( value == true ) {
                        $(this).addClass( 'ipbe-btn-success' );
                    } else {
                        $(this).addClass( 'ipbe-btn-danger' );
                    }
                    $(this).addClass( 'active' );
                }
                $( '.ipbe-onoff-value', cont ).val(value);
                
                var field = $(this).parents( '.ipbe-field-row' );
                if ( field.hasClass( 'ipbe-toggle' )) {
                    
                    if ( value == 'false' || value == false ) {
                        $( '.ipbe-toggle-option', field ).hide();
                    } else {
                        $( '.ipbe-toggle-option', field ).show();
                    }
                }
                options.func_select( cont );
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Select Active
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_select_active = function( options ) 
    {
        var defaults  = {
            cont_selector:      '.ipbe-field-row',
            item_selector:      '.ipbe-select',
            input_selector:     '.ipbe-select-input',
            class_selected:     'selected',
            func_select:         function( input ){}
        };
        var opt  = $.extend( defaults, options );
        var cont = $(this).parents( opt.cont_selector );
        $(this).click( function()
        {
            var value = $(this).data( 'value' );
            $( opt.item_selector, cont ).removeClass( opt.class_selected );
            $(this).addClass( opt.class_selected );
            $( opt.input_selector, cont ).val( value );
            
            //Select callback
            opt.func_select( $(this) );
            return false;
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Select image input
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_select_image = function( options ) 
    {
        var defaults  = {
            func_select: function( item ){},
        };
        var options = $.extend( defaults, options );
        
        var item = $(this);
        item.each( function()
        {
            var root = $(this);
            var frame;
            $( '.ipbe-btn-media', root ).click( function(e)
            {
                var $el = $(this);
                e.preventDefault();
                
                // If the media frame already exists, reopen it.
                if ( frame ) {
                    frame.open();
                    return;
                }
                // Create the media frame.
                frame = wp.media.frames.customHeader = wp.media({
                    // Set the title of the modal.
                    title: $el.data('choose'),

                    // Tell the modal to show only images.
                    library: {
                        type: 'image'
                    },

                    // Customize the submit button.
                    button: {
                        // Set the text of the button.
                        text: $el.data('update'),
                        // Tell the button not to close the modal, since we're
                        // going to refresh the page when the image is selected.
                        close: false
                    }
                });

                // When an image is selected, run a callback.
                frame.on( 'select', function() {
                    // Grab the selected attachment.
                    var attachment = frame.state().get('selection').first();
                    var id         = attachment.id;
                    var url        = attachment.attributes.sizes.thumbnail.url;
                    
                    $( '.ipbe-upload-preview .none', root ).hide();
                    $( '.ipbe-upload-preview .image', root )
                        .html( '<img src="'+url+'" alt="" />' )
                        .show();
                    $( '.ipbe-image-id', root ).val( id );
                    $( '.ipbe-btn-reset', root ).show();
                    
                    //Select callback
                    options.func_select( item );
                    
                    frame.close();
                });
                frame.open();
                
                return false;
            });
            $( '.ipbe-btn-reset', root ).click( function(e)
            {
                $( '.ipbe-upload-preview .none', root ).show();
                $( '.ipbe-upload-preview .image', root ).html( '' ).hide();
                $( '.ipbe-image-id', root ).val( 0 );
                $( '.ipbe-btn-reset', root ).hide();
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Select preview
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_select_preview = function( options ) 
    {
        var defaults  = {
            cont_selector:          '.ipbe-field-row',
            cont_preview_selector:  '.ipbe-select-preview',
            item_preview_class:     'ipbe-preview',
            root_image:             '',
            preview_data:           [],
            func_select:            function( input ){}
        };
        var opt  = $.extend( defaults, options );
        var cont = $(this).parents( opt.cont_selector );
        
        $(this).change( function()
        {
            var select  = $(this).val();
            var preview = $( opt.cont_preview_selector, cont );
            var opts    = opt.preview_data;
            preview.html( '' );
            for (var i = 0; i < opts.length; i++) 
            {
                var key = opts[i];
                var src = opt.root_image+select+'/'+key+'.png';
                preview.append(
                    '<span class="'+opt.item_preview_class+'"><img src="'+src+'" alt="'+key+'"></span>'
                );
            }
            opt.func_select( $(this) );
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Tab menu
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_stats = function( options )
    {
        var defaults  = {
            ajax_url: '',
            chart_id:  'ipbe-chart-div'
        };
        var ipbe_opt = $.extend( defaults, options );
        
        var root = $(this);
        
        //Date picker
        $( '#date-start',root )
            .datepicker()
            .bind('changeDate', function(ev){
                $( '#date-start',root ).datepicker('hide');
            });
        
        $( '#date-end', root )
            .datepicker()
            .bind('changeDate', function(ev){
                $( '#date-end',root ).datepicker('hide');
            });
        
        //Do filter date
        $( '#do-filter-date', root ).click( function()
        {
            var dateStart = $( '#date-start' ).val();
            var dateEnd   = $( '#date-end' ).val();
            var pageId    = $( '#value-pageid' ).val();
            var type      = $( '#value-stat-type' ).val();
            
            //Show loader
            $( '.ipbe-chart-main', root ).html('').hide();
            $( '.ipbe-chart-load', root ).show();
            
            $.ajax({
                url: ipbe_opt.ajax_url,
                type: "POST",
                data: 'start='+dateStart+'&end='+dateEnd+'&pageid='+pageId+'&type='+type,
                dataType: "json",
                success: function (result ) {
                
                    $( '.ipbe-chart-main' ).show();
                    $( '.ipbe-chart-load' ).hide();
                    if ( result.status == 1 && result.data.length > 0 ) 
                    {
                        var dataTable = new google.visualization.DataTable();
                        dataTable.addColumn( 'date', result.labelDate );
                        dataTable.addColumn( 'number', result.labelValue );
                        
                        var rows = [];
                        for (var i=0; i<result.data.length; i++)
                        { 
                            var cur   = result.data[i];
                            var data  = [ new Date( cur.year, cur.mon, cur.day ), cur.value ];
                            rows.push( data );
                        }
                        dataTable.addRows( rows );
                        var options = {
                            series: [{pointSize:6}]
                        };
                        var chart = new google.visualization.LineChart(document.getElementById(ipbe_opt.chart_id));
                        chart.draw(dataTable, options);
                    }
                },
                error: function () {
                    alert( "Error in get statistic data" );
                },
            });
            
            return false;
        });
        
        //Stat Nav
        $( '.ipbe-stat-nav a' ).click( function()
        {
            var link   = $(this);
            var root   = link.parents( 'li' );
            var type   = link.attr( 'href' ).replace( '#stat-', '' );
            var pageId = $( '#value-pageid' ).val();
            
            if ( root.hasClass( 'active' )) {
                return true;
            }
            $( '.ipbe-stat-nav li' ).removeClass( 'active' );
            root.addClass( 'active' );
            $( '#value-stat-type' ).val( type );
            
            //Show loader
            $( '.ipbe-chart-main' ).html('').hide();
            $( '.ipbe-chart-load' ).show();
            
            //Load cart
            $.ajax({
                url: ipbe_opt.ajax_url,
                type: "POST",
                data: 'pageid='+pageId+'&type='+type,
                dataType: "json",
                success: function (result ) {
                
                    $( '.ipbe-chart-main' ).show();
                    $( '.ipbe-chart-load' ).hide();
                    if ( result.status == 1 && result.data.length > 0 ) 
                    {
                        var dataTable = new google.visualization.DataTable();
                        dataTable.addColumn( 'date', result.labelDate );
                        dataTable.addColumn( 'number', result.labelValue );
                        
                        var rows = [];
                        for (var i=0; i<result.data.length; i++)
                        { 
                            var cur   = result.data[i];
                            var data  = [ new Date( cur.year, cur.mon, cur.day ), cur.value ];
                            rows.push( data );
                        }
                        dataTable.addRows( rows );
                        var options = {
                            series: [{pointSize:6}]
                        };
                        var chart = new google.visualization.LineChart(document.getElementById(ipbe_opt.chart_id));
                        chart.draw(dataTable, options);
                    }
                },
                error: function () {
                alert( "Error in get statistic data" );
                },
            });
            
            return false;
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Tab menu
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_tab = function(options)
    {
        var defaults  = {
            after_click:     function(){},
            tab_init:        function(){}
        };
        var opt  = $.extend( defaults, options );
        
        this.each( function()
        {
            var root = $(this);
            
            tab_init();
            
            $( '.ipbe-tab-menu a', root ).click( function()
            {
                clear_tab();
                $( this ).addClass( 'active' );
                
                var idtab = $(this).attr( 'href' ).replace( '#', '' );
                $( '#'+idtab ).show();
                $( '#ipbe-tab-selected' ).val( idtab );
                
                opt.after_click( idtab, root );
                
                return false;
            });
            
            function clear_tab() 
            {
                $( '.ipbe-tab-menu a', root ).each( function(){
                    $(this).removeClass( 'active' );
                });
                $( '.ipbe-tab-content', root ).hide();
            };
            
            function tab_init() 
            {
                clear_tab();
                $( '.ipbe-tab-content', root ).hide();
                var current = $( '#ipbe-tab-selected' ).val();
                $( '#'+current ).show();
                $( 'a[href="#'+current+'"]' ).addClass( 'active' );
                $( '#ipbe-tab-selected' ).val( current );
                
                opt.tab_init( current, root );
            };
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Toggle
 *===========================================================*/
(function($)
{
    "use strict";
    
    $.fn.ipbe_toggle = function() 
    {
        $(this).each( function()
        {
            var cont   = $(this);
            var height = $( '.ipbe-panel-body', cont ).height();
            $( '.ipbe-toggle-link', cont ).click( function()
            {
                if ( cont.hasClass( 'open' )) 
                {
                    cont.removeClass( 'open' );
                    cont.addClass( 'close' );
                    $( 'i', $(this) ).removeClass( 'ibe-minus' );
                    $( 'i', $(this) ).addClass( 'ibe-plus' );
                    $( '.ipbe-panel-body', cont )
                        .height( 'auto' )
                        .animate(
                            { height: 0 }, 500
                        );
                }
                else 
                {
                    cont.removeClass( 'close' );
                    cont.addClass( 'open' );
                    $( 'i', $(this) ).removeClass( 'ibe-plus' );
                    $( 'i', $(this) ).addClass( 'ibe-minus' );
                    $( '.ipbe-panel-body', cont )
                        .height( 0 )
                        .animate(
                            { height: height }, 500
                        );
                
                }
                return false;
            });
        });
    };
    
})(jQuery);
/*
 *===========================================================
 * Custom Script
 *===========================================================*/
(function($)
{
    "use strict";
    
    $(document).ready(function() 
    {
        //Fix height manage-sidebar
        if ( $( '.ipbe-manage-sidebar' ).length > 0 ) {
            var height = $( '.ipbe-manage-sidebar .ipbe-sidebar-inner' ).height();
            $( '.ipbe-manage-sidebar .ipbe-manage-content' ).css( 'min-height', height+20 );
        }
    });
    
})(jQuery);