<?php
if ( ! class_exists( 'IPTee_Db' )) {

    /**
     * Class for manage plugin database
     */
    class IPTee_Db
    {
        /**
         * Take db version
         *
         * @var string
         */
        public $version = '1.0';
        
        /**
         * Class construct
         *
         * @return void
         */
        public function __construct()
        {
            global $iptee_db_version;
            $iptee_db_version = $this->version;
        }
        
        /**
         * Database query
         *
         * @return string
         */
        public function query_stats()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptee_stats';
            $sql = "CREATE TABLE $table_name (
                        stat_id          int(11)             NOT NULL AUTO_INCREMENT,
                        page_id          int(11)             NOT NULL,
                        stat_date        datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        stat_view        int(11)             NOT NULL,
                        stat_order       int(11)             NOT NULL,
                        stat_contest     int(11)             NOT NULL,
                        stat_share       int(11)             NOT NULL,
                    PRIMARY KEY stat_id (stat_id),
                    KEY page_id (page_id)
            );";
            
            return $sql;
        }
        
        /**
         * Database query
         *
         * @return string
         */
        public function query_contestants()
        {
            global $wpdb;
            
            $table_name = $wpdb->prefix . 'iptee_contestants';
            $sql = "CREATE TABLE $table_name (
                        cnt_id           int(11)             NOT NULL AUTO_INCREMENT,
                        page_id          int(11)             NOT NULL,
                        cnt_ip           varchar(64)         NOT NULL,
                        cnt_key          varchar(244)        NOT NULL,
                        cnt_join_date    datetime  DEFAULT '0000-00-00 00:00:00' NOT NULL,
                        cnt_email        varchar(244)        NOT NULL,
                        cnt_name         varchar(244)        NOT NULL,
                        cnt_referral     int(11)             NOT NULL,
                    PRIMARY KEY contestant_id (cnt_id),
                    KEY page_id (page_id)
            );";
            
            return $sql;
        }
        
        /**
         * Database query
         *
         * @return string
         */
        public function query()
        {
            $sql  = '';
            $sql .= $this->query_stats();
            $sql .= $this->query_contestants();
            return $sql;
        }
        
        /**
         * install
         *
         * @return void
         */
        public function install()
        {
            global $wpdb, $iptee_db_version;
            $installed_ver = get_option( "iptee_db_version" );
            
            if( ! $installed_ver || ( $installed_ver != $iptee_db_version ) ) {

                $sql = $this->query();

                require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
                dbDelta( $sql );

                update_option( "iptee_db_version", $iptee_db_version );
            }
        }
        
        /**
         * update
         *
         * @return void
         */
        public function update()
        {
            global $iptee_db_version;
            if ( get_site_option( 'iptee_db_version' ) != $iptee_db_version ) {
                $this->install();
            }
        }
    }

}
?>