<?php
if ( ! class_exists( 'IPTee_List' )) {

    /**
     * Class for create list object
     */
    class IPTee_List
    {
        /**
         * Take query object
         * @var WP_Query
         */
        protected $_query;
        
        /**
         * Take data result
         * @var int
         */
        protected $_result;
        
        /**
         * Take number of data
         * @var int
         */
        protected $_total;
        
        /**
         * Take number of page
         * @var int
         */
        protected $_total_page;
        
        /**
         * Take page number
         * @var int
         */
        protected $_page;
        
        /**
         * Take number of data per page 
         * @var int
         */
        protected $_per_page;
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $this->_page     = $page;
            $this->_per_page = 12;
        }
        
        /**
         * Create list
         *
         * @return string
         */
        public function create()
        {
            //Get data
            $this->_get_data();
            //Build list
            return $this->_build();
        }
        
        /**
         * Render list
         *
         * @return void
         */
        public function render()
        {
            echo $this->create();
        }
        
        /**
         * Get data
         *
         * @return void
         */
        protected function _get_data()
        {
            $page     = $this->_page;
            $per_page = $this->_per_page;
            $args = array(
                'orderby'        => 'post_date',
                'order'          => 'DESC', 
                'post_type'      => 'iptee-item',
                'post_status'    => array('publish','draft'),
                'posts_per_page' => $per_page,
                'paged'          => $page
            );
            $query = new WP_Query;
            $this->_result = $query->query( $args );
            $this->_query  = $query;
            $this->_total  = $query->found_posts;
            $this->_total_page = $this->_get_total_page();
            return $this->_result;
        }
        
        /**
         * Build list
         *
         * @return void
         */
        protected function _build()
        {
            $list  = $this->_get_action_top();
            $list .= $this->_get_list();
            $list .= $this->_get_action_bottom();
            $list  = $this->_get_container( $list );
            return $list;
        }
        
        /**
         * Get list
         *
         * @return string
         */
        protected function _get_list()
        {
            $list = '<div class="ipbe-the-list">';
            if ( empty( $this->_result )) {
                $list .= $this->_get_empty_list();
            } 
            else 
            {
                $index = 1;
                foreach( $this->_result as $item ) {
                    $list .= $this->_get_list_item( $item, $index );
                    $index++;
                }
            }
            $list .= '</div>';
            return $list;
        }
        
        /**
         * Get list item
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_list_item( $item, $index )
        {
            $alt = '';
            if ( $index % 2 ) {
                $alt = ' ipbe-alt';
            }
            $result  = '<div id="iptee-item-' . $item->ID . '" class="ipbe-list-item' . $alt . '">';
            $result .= '<div class="ipbe-item-inner row">';
            $result .= $this->_get_item_main  ( $item, $index );
            $result .= $this->_get_item_action( $item, $index );
            $result .= '</div>';
            $result .= '</div>';
            return $result;
        }
        
        /**
         * Get item main
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_item_main( $item, $index )
        {
            $title  = $item->post_title;
            $date   = mysql2date( 'F d Y, h:i', $item->post_date );
            $link   = $this->_get_link_edit( $item );
            if ( $item->post_status == 'publish' ) {
                $label = '<span class="ipbe-label ipbe-label-success">' . __( 'Publish' ) . '</span>';
            } else {
                $label = '<span class="ipbe-label ipbe-label-danger">' . __( 'Draft' ) . '</span>';
            }
            $result = '<div class="col-sm-6">' .
                            '<div class="ipbe-item-main">' .
                                '<h3 class="ipbe-item-title">' . 
                                    '<a href="' . $link . '">' . $title . '</a>' . 
                                    $label .
                                '</h3>' .
                                '<p class="ipbe-item-create">' . 
                                    '<i class="ibe ibe-calendar"></i>' .
                                    $date . 
                                '</p>' .
                            '</div>' .
                       '</div>';
            return $result;
        }
        
        /**
         * Get item action
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_item_action( $item, $index )
        {
            $result  = '<div class="col-sm-6">' .
                            '<div class="ipbe-item-action ipbe-clear text-right">' .
                            
                                $this->_get_item_stat( $item, $index ).
                                
                                '<div class="ipbe-item-nav ipbe-fade-menu">' .
                                    '<div class="ipbe-nav-label">' .
                                        '<a class="ipbe-menu-link" href="#"><i class="ibe ibe-bars"></i></a>' .
                                    '</div>' .
                                    '<ul class="ipbe-submenu">' .
                                        '<li>' .
                                            '<a href="' . $this->_get_link_edit( $item ) . '" class="ipbe-btn ipbe-btn-success">' .
                                                '<i class="ibe ibe-pencil"></i>' .
                                                 __( 'Edit Contest' ) . 
                                            '</a>' .
                                        '</li>' .
                                        '<li>' .
                                            '<a href="' . $this->_get_link_view( $item ) . '" class="ipbe-btn ipbe-btn-primary" target="_blank">' .
                                                '<i class="ibe ibe-eye"></i>' .
                                                 __( 'View Contest' ) . 
                                            '</a>' .
                                        '</li>' .
                                        '<li>' .
                                            '<a href="#" class="ipbe-btn ipbe-btn-danger iptee-item-delete" data-id="' . $item->ID . '">' .
                                                '<i class="ibe ibe-trash"></i>' .
                                                __( 'Delete Contest' ) . 
                                            '</a>' .
                                        '</li>' .
                                    '</ul>' .
                                '</div>' .
                            '</div>' .
                       '</div>';
            return $result;
        }
        
        /**
         * Get link edit
         *
         * @param  object $item
         * @return string
         */
        protected function _get_link_edit( $item )
        {
            $link = admin_url() . 'admin.php?page=iptee&action=edit&id=' . $item->ID;
            return $link;
        }
        
        /**
         * Get link view
         *
         * @param  object $item
         * @return string
         */
        protected function _get_link_view( $item )
        {
            $home = get_home_url();
            $base = get_option( '__iptee_base_path', 'contest' );
            
            if ( get_option( 'permalink_structure' ) )  {
                $link = $home . "/$base/" . $item->post_name;
            } else {
                $link = $home . '/?contest_id=' . $item->ID . '&iptee=1';
            }
            
            return $link;
        }
        
        /**
         * Get item action
         *
         * @param  object $item
         * @param  int    $index
         * @return string
         */
        protected function _get_item_stat( $item, $index )
        {
            $model    = new IPTee_Model();
            $views    = $model->get_stat_value( $item->ID, 'view' );
            $clicks   = $model->get_stat_value( $item->ID, 'contest' );
            $convRate = 0;
            if( $clicks != '0' && $views != '0') {
                $convRate = 100 * intval($clicks) / intval($views);
                $convRate = round( $convRate, 2 );
            }
            $result  = '<div class="ipbe-item-stats">' .
                            '<div class="ipbe-clear">' .
                                '<div class="ipbe-stat ipbe-stat-view">' .
                                    '<div class="ipbe-stat-value">' .
                                        '<strong>' . $model->restyle_text( $views ) . '</strong>' .
                                    '</div>' .
                                    '<div class="ipbe-stat-label">' .
                                        '<i class="ibe ibe-eye"></i>' .
                                        '<em>' . __( 'Views', 'wp_tee_contest' ) . '</em>' .
                                    '</div>' .
                                '</div>' .
                                '<div class="ipbe-stat ipbe-stat-click">' .
                                    '<div class="ipbe-stat-value">' .
                                        '<strong>' . $model->restyle_text( $clicks ) . '</strong>' .
                                    '</div>' .
                                    '<div class="ipbe-stat-label">' .
                                        '<i class="ibe ibe-users"></i>' .
                                        '<em>' . __( 'Contestants', 'wp_tee_contest' ) . '</em>' .
                                    '</div>' .
                                '</div>' .
                                '<div class="ipbe-stat ipbe-stat-conv-rate">' .
                                    '<div class="ipbe-stat-value">' .
                                        '<strong>' . $convRate . '%</strong>' .
                                    '</div>' .
                                    '<div class="ipbe-stat-label">' .
                                        '<i class="ibe ibe-line-chart"></i>' .
                                        '<em>' . __( 'Conv.Rate', 'wp_tee_contest' ) . '</em>' .
                                    '</div>' .
                                '</div>' .
                            '</div>' .
                       '</div>';
            
            return $result;
        }
        
        /**
         * Get empty list
         *
         * @return string
         */
        protected function _get_empty_list()
        {
            return '<div class="ipbe-list-empty">' .
                        '<p><em>' . __( 'Data not available', 'wp_tee_contest' ) . '</em></p>' .
                    '</div>';
        }
        
        /**
         * Get pagination
         *
         * @return string
         */
        protected function _get_pagination()
        {
            $result = '';
            if ( $this->_need_pagination() )
            {
                $result = '<div class="ipbe-pagination ipbe-clear">' .
                            $this->_get_pagination_total() .
                            $this->_get_pagination_menu() .
                          '</div>';
            }
            return $result;
        }
        
        /**
         * Check is need pagination or not
         *
         * @return string
         */
        protected function _need_pagination()
        {
            $is_need = false;
            if ( ! empty( $this->_result ) && $this->_total_page > 1 ) {
                $is_need = true;
            }
            return $is_need;
        }
        
        /**
         * Get total page
         *
         * @return int
         */
        protected function _get_total_page()
        {
            $total_page = ceil( $this->_total/$this->_per_page );
            return $total_page;
        }
        
        /**
         * Get pagination total info
         *
         * @return string
         */
        protected function _get_pagination_total()
        {
            $total  = $this->_total;
            $result = '<div class="ipbe-total">' .
                        sprintf( _n( '1 item', '%s items', $total, 'wp_tee_contest' ), $total ) .
                      '</div>';
            return $result;
        }
        
        /**
         * Get pagination menu
         *
         * @return string
         */
        protected function _get_pagination_menu()
        {
            $result = '<div class="ipbe-pagination-menu">' .
                        $this->_get_pagination_first() .
                        $this->_get_pagination_previous() .
                        $this->_get_pagination_page_info() .
                        $this->_get_pagination_next() .
                        $this->_get_pagination_last() .
                      '</div>';
            return $result;
        }
        
        /**
         * Get pagination go first menu
         *
         * @return string
         */
        protected function _get_pagination_first()
        {
            $result = '';
            $link   = $this->_get_pagination_link( 1 );
            $class  = 'ipbe-pagin ipbe-pagin-first';
            if ( $this->_page == 1 || $this->_total_page < 3 ) {
                $class .= ' disabled';
            }
            $result = '<a class="' . $class . '" href="' . $link . '"><i class="ibe ibe-angle-double-left"></i></a>';
            return $result;
        }
        
        /**
         * Get pagination go last menu
         *
         * @return string
         */
        protected function _get_pagination_last()
        {
            $result = '';
            $link   = $this->_get_pagination_link( $this->_total_page );
            $class  = 'ipbe-pagin ipbe-pagin-last';
            if ( $this->_page == $this->_total_page || $this->_total_page < 3 ) {
                $class .= ' disabled';
            }
            $result = '<a class="' . $class . '" href="' . $link . '"><i class="ibe ibe-angle-double-right"></i></a>';
            return $result;
        }
        
        /**
         * Get pagination previous menu
         *
         * @return string
         */
        protected function _get_pagination_previous()
        {
            $result = '';
            $class  = 'ipbe-pagin ipbe-pagin-previous';
            $page   = $this->_page - 1;
            if ( $page < 1 ) {
                $page = 1;
                $class .= ' disabled';
            }
            $link = $this->_get_pagination_link( $page );
            $result = '<a class="' . $class . '" href="' . $link . '"><i class="ibe ibe-angle-left"></i></a>';
            return $result;
        }
        
        /**
         * Get pagination next menu
         *
         * @return string
         */
        protected function _get_pagination_next()
        {
            $result = '';
            $class  = 'ipbe-pagin ipbe-pagin-next';
            $page   = $this->_page + 1;
            if ( $page > $this->_total_page ) {
                $page = $this->_total_page;
                $class .= ' disabled';
            }
            $link = $this->_get_pagination_link( $page );
            $result = '<a class="' . $class . '" href="' . $link . '"><i class="ibe ibe-angle-right"></i></a>';
            return $result;
        }
        
        /**
         * Get pagination link
         *
         * @param  int $page
         * @return string
         */
        protected function _get_pagination_link( $page )
        {
            $link = admin_url() . '?page=iptee&paged=' . $page;
            return $link;
        }
        
        /**
         * Get pagination page info
         *
         * @return string
         */
        protected function _get_pagination_page_info()
        {
            $result = '<span class="ipbe-paged-info">' . 
                        '<strong>' . $this->_page . '</strong> of <strong>' . $this->_total_page . '</strong>' .
                      '</span>';
            return $result;
        }
        
        /**
         * Get container
         *
         * @param  string $list
         * @return string
         */
        protected function _get_container( $list )
        {
            $result = '<div class="ipbe-manage container-fluid container">' .
                        '<div class="ipbe-manage-list ipbe-list-stat">' .
                            $list .
                        '</div>' .
                      '</div>';
            
            return $result;
        }
        
        /**
         * Get action top
         *
         * @return string
         */
        protected function _get_action_top()
        {
            return '';
        }
        
        /**
         * Get action bottom
         *
         * @return string
         */
        protected function _get_action_bottom()
        {
            $action = '<div class="ipbe-action-bottom">' .
                        '<div class="row">' .
                            '<div class="col-sm-6"></div>' . 
                            '<div class="col-sm-6 text-right">' .
                                $this->_get_pagination() .
                            '</div>' .
                        '</div>' .
                      '</div>';
            return $action;
        }
    }

}
?>