<?php
if ( ! class_exists( 'IPTee_Setting' )) {

    /**
     * Class for manage post setting
     */
    class IPTee_Setting
    {
        /**
         * Take post id
         *
         * @var string
         */
        protected $_postId;
        
        /**
         * Take setting name
         *
         * @var string
         */
        protected $_name;
        
        /**
         * Take post setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @param int $postId
         * @param string $name
         * @return void
         */
        public function __construct( $postId, $name )
        {
            $this->_postId = absint( $postId );
            $this->_name   = $name;
            $this->_prepare();
        }
        
        /**
         * Get all post setting
         *
         * @return string
         */
        public function getSettings()
        {
            return $this->_settings;
        }
        
        /**
         * Get post setting
         *
         * @param  string $key
         * @param  mixed  $default
         * @return string
         */
        public function getSetting( $key, $default = false, $allowEmpty = false )
        {
            $setting = $default;
            if ( $allowEmpty ) {
                if ( isset( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            } else {
                if ( ! empty( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            }
            return $setting;
        }
        
        /**
         * Add setting
         *
         * @param  array $data
         * @return boolean
         */
        public function addSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
        }
        
        /**
         * Set all post setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Set post setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
            $data = array(
                $key => $value
            );
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Reset post setting
         *
         * @return boolean
         */
        public function reset()
        {
            $data = array( 'reset' => 1 );
            return $this->_update( $data );
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $id = $this->_postId;
            if ( ! empty( $id )) {
                $metas = get_post_meta( $id, $this->_name );
                $meta  = array_shift( $metas );
                $this->_settings = maybe_unserialize( $meta );
            }
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
            $settings = (array)$settings;
            return update_post_meta( $this->_postId, $this->_name, $settings );
        }
    }

}
?>