<?php
/*
Plugin Name: WP Tee Contest
Plugin URI: 
Description: Plugin that can be used to create the contest page to collect Leads and Go Viral
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPTEE_TITLE', 'WP Tee Contest' );
define( 'IPTEE_FILE', __FILE__ );
define( 'IPTEE_PATH', plugin_dir_path( __FILE__ ) );
define( 'IPTEE_BASE_URL', plugin_dir_url( __FILE__ ) );

require_once( IPTEE_PATH . "app/setting.php" );
require_once( IPTEE_PATH . "app/db.php" );
require_once( IPTEE_PATH . "app/ajax.php" );
require_once( IPTEE_PATH . "app/admin.php" );
require_once( IPTEE_PATH . "app/list.php" );
require_once( IPTEE_PATH . "app/form.php" );
require_once( IPTEE_PATH . "app/font.php" );
require_once( IPTEE_PATH . "app/model.php" );
require_once( IPTEE_PATH . "app/factory.php" );
/* 
require_once( IPTEE_PATH . "app/faicon.php" ); */

/**
 * Main class
 */
if ( ! class_exists( 'IPTee' )) {

    class IPTee
    {
        /**
         * Setup Plugin
         */
        public static function setup()
        {
            $hook = sanitize_title( IPTEE_TITLE );
            
            //Register admin menu
            add_action( 'admin_menu', array( __CLASS__, 'add_admin_menu' ) );
            
            //Plugin init
            add_action( 'admin_init', array( __CLASS__, 'admin_init' ) );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( __CLASS__, 'install' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( __CLASS__, 'update_db' ) );
            
            //Rewrite Handler
            add_action( 'init', array( __CLASS__, 'rewrite_flush' ) );
            add_action( 'pre_get_posts', array( __CLASS__, 'init' ) );
            
            //Render page
            add_action( 'template_redirect', array( __CLASS__, 'factory' ) );
             
            //Add admin style & script
            add_action( 'admin_print_styles', array( __CLASS__, 'admin_style_global' ), 1000 );
            add_action( 'admin_print_styles-toplevel_page_iptee', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptee-add', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptee-statistic', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptee-setting', array( __CLASS__, 'admin_style' ), 1000 );
            add_action( 'admin_print_styles-'.$hook.'_page_iptee-support', array( __CLASS__, 'admin_style' ), 1000 );
            
            add_action( 'admin_print_scripts-toplevel_page_iptee', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptee-add', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptee-statistic', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptee-setting', array( __CLASS__, 'admin_script' ), 1000 );
            add_action( 'admin_print_scripts-'.$hook.'_page_iptee-support', array( __CLASS__, 'admin_script' ), 1000 );
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public static function add_admin_menu()
        {
            add_menu_page( 
                IPTEE_TITLE, 
                IPTEE_TITLE, 
                'iptee_manage', 
                'iptee',
                array( __CLASS__, 'admin' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'iptee',
                __( 'Dashboard', 'wp_tee_contest' ), 
                __( 'Dashboard', 'wp_tee_contest' ), 
                'iptee_manage', 
                'iptee',
                array( __CLASS__, 'admin' )
            );
            add_submenu_page( 
                'iptee',
                __( 'Add Contest Page', 'wp_tee_contest' ), 
                __( 'Add Contest Page', 'wp_tee_contest' ), 
                'iptee_manage', 
                'iptee-add',
                array( __CLASS__, 'admin_add' )
            );
            add_submenu_page( 
                'iptee',
                __( 'Settings', 'wp_tee_contest' ), 
                __( 'Settings', 'wp_tee_contest' ), 
                'iptee_manage', 
                'iptee-setting',
                array( __CLASS__, 'admin_setting' )
            );
        }
        
        /**
         * Admin Init
         *
         * @return void
         */
        public static function admin_init()
        {
            global $wp_roles;
            
            /** 
             * Register Roles
             */
            // Add capability for administrator
            $role = get_role( 'administrator' );
            $role->add_cap( 'iptee_manage' );
            
            $wp_roles->reinit();
            
            /**
             * Ajax handler
             **/
            $ajax = new IPTee_Ajax();
            $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public static function admin()
        {
            $display = new IPTee_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator add contest page
         *
         * @return void
         */
        public static function admin_add()
        {
            $display = new IPTee_Admin();
            $display->add();
        }
        
        /**
         * Content for administrator setting page
         *
         * @return void
         */
        public static function admin_setting()
        {
            $display = new IPTee_Admin();
            $display->setting();
        }
        
        /**
         * Install plugin
         *
         * @return void
         */
        public static function install()
        {
            //Rewrite
            self::rewriteInit();
            flush_rewrite_rules();
            
            //Db
            $db = new IPTee_Db();
            $db->install();
        }
        
        /**
         * Update database
         *
         * @return void
         */
        public static function update_db()
        {
            $db = new IPTee_Db();
            $db->update();
        }
        
        /**
         * Init request
         *
         * @return void
         */
        public static function init( $query )
        {
            $q = $query->query;
            if ( isset( $q['iptee'] ) && isset( $q['contest_name'] )) {
                $query->query_vars['post_type'] = 'iptee-item';
                $query->query_vars['name']      = $q['contest_name'];
                $query->query_vars['pagename']  = $q['contest_name'];
                $query->query['pagename']       = $q['contest_name'];
            
            } elseif( isset( $q['contest_id'] )) {
                $query->query_vars['post_type'] = 'iptee-item';
                $query->query_vars['p']         = absint( $q['contest_id'] );
            }
        }
        
        /**
         * Init rewrite rule
         *
         * @return void
         */
        public static function rewriteInit()
        {
            $base = get_option( '__iptee_base_path', 'contest' );
            add_rewrite_rule(
                $base . '/([^/]+)/?$',
                'index.php?iptee=1&contest_name=$matches[1]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/feed/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?iptee=1&contest_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/(feed|rdf|rss|rss2|atom)/?$',
                'index.php?iptee=1&contest_name=$matches[1]&feed=$matches[2]',
                'top'
            );
            add_rewrite_rule(
                $base . '/([^/]+)/page/?([0-9]{1,})/?$',
                'index.php?iptee=1&contest_name=$matches[1]&paged=$matches[2]',
                'top'
            );
            add_rewrite_tag( '%contest_name%', '([a-zA-Z0-9\_])');
            add_rewrite_tag( '%contest_id%', '([0-9])');
            add_rewrite_tag( '%iptee%', '([1])');
        }
        
        /**
         * Flush rewrite rule
         *
         * @return void
         */
        public static function rewrite_flush()
        {
            $base = get_option( '__iptee_base_path', 'contest' );
            $old  = get_option( '__iptee_base_path_old', 'contest' );
            
            self::rewriteInit();
            
            if ( $base != $old ) {
                flush_rewrite_rules();
                update_option( '__iptee_base_path_old', $base );
            }
        }
        
        /**
         * Video page factory
         *
         * @return void
         */
        public static function factory()
        {
            //Factory
            $factory = new IPTee_Factory();
            $factory->render();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style()
        {
            wp_deregister_style('insta-backend-style');
            wp_register_style('insta-backend-style', plugin_dir_url( __FILE__ ) . 'css/ipbe-admin.css', false, null);
            wp_enqueue_style('insta-backend-style');
            
            wp_deregister_style('iptee-admin-style');
            wp_register_style('iptee-admin-style', plugin_dir_url( __FILE__ ) . 'css/admin.css', false, null);
            wp_enqueue_style('iptee-admin-style');
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public static function admin_style_global()
        {
            wp_deregister_style('iptee-admin-style-global');
            wp_register_style('iptee-admin-style-global', plugin_dir_url( __FILE__ ) . 'css/admin-global.css', false, null);
            wp_enqueue_style('iptee-admin-style-global');
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public static function admin_script($hook)
        {
        ?>
        <script type="text/javascript">
            var iptee_img_url = '<?php echo IPTEE_BASE_URL . 'img/'; ?>',
                ipbe_base       = '<?php echo IPTEE_BASE_URL; ?>',
                ip_ui_message   = 
                {
                    delete_confirm_title: '<?php _e( 'Delete Confirmation', 'wp_tee_contest' ); ?>',
                    delete_confirm_info: '<?php _e( 'Are you sure doing this action?', 'wp_tee_contest' ); ?>'
                };
        </script>
        <?php
            wp_deregister_script('insta-backend-script');
            wp_enqueue_script(
                'insta-backend-script',
                plugin_dir_url( __FILE__ ) . 'js/ipbe-admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
            wp_deregister_script('iptee-admin-script');
            wp_enqueue_script(
                'iptee-admin-script',
                plugin_dir_url( __FILE__ ) . 'js/admin.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Print public style
         *
         * @return void
         */
        public static function public_style()
        {
            global $iptee;
            
            if ( ! $iptee ) {
                $iptee = new IPTee_Factory();
            }
            $setting = $iptee->setting();
            $name    = $setting->getSetting( 'font_family', 'roboto' );
            $fonts   = IPTee_Font::getLinks();
            if ( array_key_exists( $name, $fonts )) 
            {
                $family  = $fonts[$name];
                $fontUrl = 'http://fonts.googleapis.com/css?family=' . $family;
                echo '<link id="iptee-font" href="' . $fontUrl . '" rel="stylesheet" type="text/css">';
            }
        ?>
            <script type="text/javascript">
                var iptee_ajaxurl = "<?php echo admin_url( 'admin-ajax.php' ); ?>";
                var iptee_scroll  = "<?php echo $setting->getSetting( 'scroll_show', 0 ); ?>";
            </script>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/public.min.css" rel="stylesheet">
        <?php
        }

        /**
         * Print public script
         *
         * @return void
         */
        public static function public_script()
        {
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
            
            wp_deregister_script('iptee-public-script');
            wp_enqueue_script(
                'iptee-public-script',
                plugin_dir_url( __FILE__ ) . 'js/public.min.js',
                array( 'jquery' ),
                1,
                true
            );
        }
    }

}
//Run plugin
IPTee::setup();
?>